ChangeSet 1.946.3.19, 2002/12/27 10:36:37-08:00, dmitri@users.sourceforge.net

[PATCH] Extra parameters removed from the ultracam driver

> > Ultracam was derived from ibmcam and probably copied the list of
> > parameters too. IBM cameras have this parameter, and use it.
>
> This means that it says "MODULE_PARM(lighting, "i");" and there is no
> variable called lightening.  The new module code is stricter about
> this.  Someone please fix.

Here is the patch for 2.5.53. It removes parameters that have no use
in the ultracam driver (and they were broken anyway).


diff -Nru a/drivers/usb/media/ultracam.c b/drivers/usb/media/ultracam.c
--- a/drivers/usb/media/ultracam.c	Fri Dec 27 23:56:50 2002
+++ b/drivers/usb/media/ultracam.c	Fri Dec 27 23:56:50 2002
@@ -1,5 +1,8 @@
 /*
  * USB NB Camera driver
+ *
+ * HISTORY:
+ * 25-Dec-2002 Dmitri      Removed lighting, sharpness parameters, methods.
  */
 
 #include <linux/kernel.h>
@@ -34,12 +37,6 @@
 static const int min_canvasWidth  = 8;
 static const int min_canvasHeight = 4;
 
-//static int lighting = 1; /* Medium */
-
-#define SHARPNESS_MIN	0
-#define SHARPNESS_MAX	6
-//static int sharpness = 4; /* Low noise, good details */
-
 #define FRAMERATE_MIN	0
 #define FRAMERATE_MAX	6
 static int framerate = -1;
@@ -77,10 +74,6 @@
 		"6=clean frames");
 MODULE_PARM(framerate, "i");
 MODULE_PARM_DESC(framerate, "Framerate setting: 0=slowest, 6=fastest (default=2)");
-MODULE_PARM(lighting, "i");
-MODULE_PARM_DESC(lighting, "Photosensitivity: 0=bright, 1=medium (default), 2=low light");
-MODULE_PARM(sharpness, "i");
-MODULE_PARM_DESC(sharpness, "Model1 noise reduction: 0=smooth, 6=sharp (default=4)");
 
 MODULE_PARM(init_brightness, "i");
 MODULE_PARM_DESC(init_brightness, "Brightness preconfiguration: 0-255 (default=128)");
@@ -206,24 +199,6 @@
 }
 
 /*
- * ultracam_change_lighting_conditions()
- */
-static void ultracam_change_lighting_conditions(struct uvd *uvd)
-{
-}
-
-/*
- * ultracam_set_sharpness()
- *
- * Cameras model 1 have internal smoothing feature. It is controlled by value in
- * range [0..6], where 0 is most smooth and 6 is most sharp (raw image, I guess).
- * Recommended value is 4. Cameras model 2 do not have this feature at all.
- */
-static void ultracam_set_sharpness(struct uvd *uvd)
-{
-}
-
-/*
  * ultracam_set_brightness()
  *
  * This procedure changes brightness of the picture.
@@ -272,8 +247,6 @@
 
 static void ultracam_video_start(struct uvd *uvd)
 {
-	ultracam_change_lighting_conditions(uvd);
-	ultracam_set_sharpness(uvd);
 	ultracam_reinit_iso(uvd, 0);
 }
 
